import React from 'react';
import { Icon, Button, Input, Select, Spin, Table, DatePicker, message, Cascader, Switch } from 'antd';
import { provinceArr } from '../../../dataDic.js';
import { getTime, companySearch, getCopyrightState, getInUrgentTime } from '../../../tools.js';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import PatentAdd from './comPatentAdd.jsx';
import PatentChange from './comPatentChange.jsx';

import moment from 'moment';
import './copyright.less';

const copyright = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/copyright/list",
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                locationProvince: this.state.province,
                unitName: this.state.unitName,
                copyrightName: this.state.copyrightName,
                status: this.state.status,
                createTime: this.state.createTime,
                acceptTime: this.state.acceptTime,
                authTime: this.state.authTime
            },
            success: function (data) {
                if (data.error.length || !data.data || !data.data.list) {
                    message.warning(data.error[0].message);
                    return;
                };
                for (let i = 0; i < data.data.list.length; i++) {
                    let thisdata = data.data.list[i];
                    this.state.data.push({
                        key: i,
                        id: thisdata.id,
                        uid: thisdata.uid,
                        province: thisdata.province,
                        unitName: thisdata.unitName,
                        serialNumber: thisdata.serialNumber,
                        createTime: thisdata.createTime,
                        acceptTime: thisdata.acceptTime,
                        principal: thisdata.principal,
                        contact: thisdata.contact,
                        copyrightName: thisdata.copyrightName,
                        status: thisdata.status,
                        comment: thisdata.comment,
                        workIssue: thisdata.workIssue,
                        outsource: thisdata.outsource,
                        inUrgent: thisdata.inUrgent,
                        expectTime: [moment(thisdata.acceptTime), thisdata.inUrgent],
                        authorizedDate: thisdata.authorizedDate,
                        fisrtContact: thisdata.fisrtContact,
                        secondContact: thisdata.secondContact,
                        thirdContact: thisdata.thirdContact,
                        authorizedDateFormattedDate: thisdata.authorizedDateFormattedDate,
                        createTimeFormattedDate: thisdata.createTimeFormattedDate,
                        acceptTimeFormattedDate: thisdata.acceptTimeFormattedDate
                    });
                };
                this.state.pagination.defaultCurrent = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                this.setState({
                    dataSource: this.state.data,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getAuthorList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/techservice/patent/getAdmin",
            success: function (data) {
                if (data.error.length || !data.data) {
                    return;
                };
                let _me = this;
                for (var item in data.data) {
                    _me.state.authorOption.push(
                        <Select.Option value={item} key={item}>{data.data[item]}</Select.Option>
                    )
                };
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getCompanyList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/techservice/patent/getUnitNames",
            success: function (data) {
                if (data.error.length || !data.data) {
                    return;
                };
                let _me = this;
                for (var item in data.data) {
                    _me.state.companyOption.push(
                        <Select.Option value={item} key={item}>{data.data[item]}</Select.Option>
                    )
                };
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            visible: false,
            provinceOption: [],
            companyOption: [],
            authorOption: [],
            data: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            showAdd: false,
            showDesc: false,
            searchMore: true,
            createTime: [],
            acceptTime: [],
            authTime: [],
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '省份',
                    dataIndex: 'province',
                    key: 'province',
                }, {
                    title: '外包公司',
                    dataIndex: 'outsource',
                    key: 'outsource',
                }, {
                    title: '公司名称',
                    dataIndex: 'unitName',
                    key: 'unitName',
                }, {
                    title: '认证状态',
                    dataIndex: 'status',
                    key: 'status',
                    render: (text) => { return getCopyrightState(text) }
                }, {
                    title: '派单信息',
                    dataIndex: 'workIssue',
                    key: 'workIssue',
                }, {
                    title: '软著名称',
                    dataIndex: 'copyrightName',
                    key: 'copyrightName',
                }, {
                    title: '加急天数',
                    dataIndex: 'inUrgent',
                    key: 'inUrgent',
                }, {
                    title: '咨询师',
                    dataIndex: 'principal',
                    key: 'principal',
                }, {
                    title: '派单日',
                    dataIndex: 'createTimeFormattedDate',
                    key: 'createTimeFormattedDate',
                }, {
                    title: '受理日',
                    dataIndex: 'acceptTimeFormattedDate',
                    key: 'acceptTimeFormattedDate',
                }, {
                    title: '(预计)下证时间',
                    dataIndex: 'expectTime',
                    key: 'expectTime',
                    render: (text) => { return getTime(getInUrgentTime(text[0], text[1])) }
                }, {
                    title: '备注',
                    dataIndex: 'comment',
                    key: 'comment',
                }
            ],
            dataSource: []
        };
    },
    componentWillMount() {
        let _me = this;
        provinceArr.map(function (item) {
            _me.state.provinceOption.push(
                <Select.Option value={item} key={item}>{item}</Select.Option>
            )
        });
        //console.log(this.state.pagination.total);
        this.loadData();
        this.getAuthorList();
        this.getCompanyList();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true
        });
    },
    delectRow() {
        let deletedIds = [];
        for (let idx = 0; idx < this.state.selectedRows.length; idx++) {
            let rowItem = this.state.selectedRows[idx];
            if (rowItem.id) {
                deletedIds.push(rowItem.id)
            }
        }
        this.setState({
            selectedRowKeys: [],
            loading: deletedIds.length > 0
        });
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/copyright/delete",
            data: {
                id: deletedIds
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('保存成功！');
                this.setState({
                    loading: false,
                });
            } else {
                message.warning(data.error[0].message);
            };
            this.loadData();
        }.bind(this));
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            this.loadData();
        };
    },
    addClick() {
        this.setState({
            showAdd: true
        });
    },
    closeAdd(e, s) {
        this.state.showAdd = e;
        if (s) {
            this.loadData();
        };
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.province = undefined;
        this.state.unitName = undefined;
        this.state.createTime = [];
        this.state.acceptTime = [];
        this.state.authTime = [];
        this.loadData();
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows,
                    selectedRowKeys: selectedRowKeys
                });
            }
        };
        const hasSelected = this.state.selectedRowKeys.length > 0;
        const { MonthPicker, RangePicker } = DatePicker;
        return (
            <div className="foster-box">
                <div className="foster-content">
                    <div className="content-title">
                        <span>软著申请管理</span>
                        <PatentAdd
                            companyOption={this.state.companyOption}
                            authorOption={this.state.authorOption}
                            onClick={this.addClick}
                            closeAdd={this.closeAdd} />
                    </div>
                    <div className="foster-query">
                        <Select placeholder="选择省份"
                            style={{ width: 200 }}
                            value={this.state.province}
                            showSearch
                            filterOption={companySearch}
                            onChange={(e) => { this.setState({ province: e }) }}>
                            {this.state.provinceOption}
                        </Select>
                        <Select placeholder="选择公司"
                            style={{ width: 200 }}
                            value={this.state.unitName}
                            showSearch
                            filterOption={companySearch}
                            onChange={(e) => { this.setState({ unitName: e }) }}>
                            {this.state.companyOption}
                        </Select>
                        <span>更多搜索<Switch defaultChecked={false} onChange={this.searchSwitch} /></span>
                        <Button type="primary" onClick={this.search}>搜索</Button>
                        <Button onClick={this.reset}>重置</Button>
                        <Button style={{ background: "#3fcf9e", border: "none", color: "#fff" }}
                            disabled={!hasSelected}
                            onClick={this.delectRow}>删除<Icon type="minus" /></Button>
                        <div className="search-more" style={this.state.searchMore ? { display: 'none' } : {}}>
                            <span>派单时间:</span>
                            <RangePicker style={{ width: '240px' }}
                                allowClear={false}
                                value={[moment(this.state.createTime[0]), moment(this.state.createTime[1])]}
                                onChange={(date, dateString) => { this.setState({ createTime: dateString }) }} />
                            <span>受理时间:</span>
                            <RangePicker style={{ width: '240px' }}
                                allowClear={false}
                                value={[moment(this.state.acceptTime[0]), moment(this.state.acceptTime[1])]}
                                onChange={(date, dateString) => { this.setState({ acceptTime: dateString }) }} />
                            <span>下证时间:</span>
                            <RangePicker style={{ width: '240px' }}
                                allowClear={false}
                                value={[moment(this.state.authTime[0]), moment(this.state.authTime[1])]}
                                onChange={(date, dateString) => { this.setState({ authTime: dateString }) }} />
                        </div>
                    </div>
                    <div className="foster-table">
                        <Spin spinning={this.state.loading}>
                            <Table columns={this.state.columns}
                                rowSelection={rowSelection}
                                dataSource={this.state.dataSource}
                                pagination={this.state.pagination}
                                onRowClick={this.tableRowClick} />
                        </Spin>
                    </div>
                    <PatentChange
                        data={this.state.RowData}
                        authorOption={this.state.authorOption}
                        showDesc={this.state.showDesc}
                        closeDesc={this.closeDesc} />
                </div >
            </div>
        );
    }
});

export default copyright;