import React from 'react';
import { Icon, Button, Select, Spin, Table, message } from 'antd';
import { companySearch, getTechnologyState } from '../../tools.js';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import './technology.less';

import ApplyAdd from './technologyAdd.jsx';
import ApplyChange from './technologyChange.jsx';


const Technology = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            loading: true
        });
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/techproject/listClientTechProject",
            success: function (data) {
                if (data.error.length || !data.data || !data.data.list) {
                    message.warning(data.error[0].message);
                    return;
                }
                for (let i = 0; i < data.data.list.length; i++) {
                    let thisdata = data.data.list[i];
                    switch (thisdata.contacts){
                    	case 1:
                    		thisdata.contacts = thisdata.firstContacts;
                    		break;
                    	case 2:
                    		thisdata.contacts = thisdata.secondContacts;
                    		break;
                    	case 3:
                    		thisdata.contacts = thisdata.thirdContacts;
                    		break;
                    }
                    this.state.data.push({
                        key: i,
                        pid: thisdata.id,
                        uid: thisdata.uid,
                        serialNumber: thisdata.serialNumber,
                        province: thisdata.province,
                        unitName: thisdata.unitName,
                        contacts: thisdata.contacts,
                        projectName: thisdata.projectName,
                        projectCatagory: thisdata.projectCatagory,
                        techField: thisdata.techField,
                        state: thisdata.state,
                        createTime: thisdata.createTimeFormattedDate,
                        consultant: thisdata.consultant
                    });
                };
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                this.setState({
                    dataSource: this.state.data,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getAuthorList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/techservice/patent/getAdmin",
            success: function (data) {
                if (data.error.length || !data.data) {
                    return;
                };
                let _me = this;
                for (var item in data.data) {
                    _me.state.authorOption.push(
                        <Select.Option value={item} key={item}>{data.data[item]}</Select.Option>
                    )
                };
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            authorOption: [],
            selectedRows: [],
            loading: false,
            showAdd: false,
            showDesc: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber'
                }, {
                    title: '省份',
                    dataIndex: 'province',
                    key: 'province'
                }, {
                    title: '公司',
                    dataIndex: 'unitName',
                    key: 'unitName'
                }, {
                    title: '联系方式',
                    dataIndex: 'contacts',
                    key: 'contacts'
                }, {
                    title: '项目名称',
                    dataIndex: 'projectName',
                    key: 'projectName'
                }, {
                    title: '项目类型',
                    dataIndex: 'projectCatagory',
                    key: 'projectCatagory'
                },{
                    title: '技术领域',
                    dataIndex: 'techField',
                    key: 'techField'
                }, {
                    title: '项目情况',
                    dataIndex: 'state',
                    key: 'state',
                    render: text => { return getTechnologyState(text) },
                },{
                    title: '派单日',
                    dataIndex: 'createTime',
                    key: 'createTime'
                }, {
                    title: '咨询师',
                    dataIndex: 'consultant',
                    key: 'consultant'
                }
            ],
            dataSource: []
        };
    },
    componentWillMount() {
        this.loadData();
        this.getAuthorList();
        //        this.getContactsList();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true
        });
    },
    addClick() {
        this.setState({
            showAdd: true
        });
    },
    delectRow() {
        let deletedIds = [];
        for (let idx = 0; idx < this.state.selectedRows.length; idx++) {
            let rowItem = this.state.selectedRows[idx];
            if (rowItem.id) {
                deletedIds.push(rowItem.id)
            }
        }

        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/techservice/cognizance/deleteCognizance",
            data: {
                ids: deletedIds
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('保存成功！');
                this.setState({
                    loading: false,
                });
            } else {
                message.warning(data.error[0].message);
            };
            this.loadData();
        }.bind(this));
    },
    closeDesc(e) {
        this.state.showDesc = e;
        this.loadData();
    },
    closeAdd(e) {
        this.state.showAdd = e;
        this.loadData();
    },
    render() {
        return (
            <div className="foster-content" >
                <div className="content-title">
                    <span>科技项目申报管理</span>
                    <div className="foster-query" style={{ float: "right" }}>
	                    <div>
	                        <Button style={{ background: "#ea0862", border: "none", color: "#fff" }}
	                            onClick={this.addClick}>申请新科技项目<Icon type="plus" /></Button>
	                    </div>
	                </div>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            pagination={this.state.pagination}
                            onRowClick={this.tableRowClick} />
                    </Spin>
                </div>
                <ApplyChange
                    data={this.state.RowData}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
                <ApplyAdd
                    authorOption={this.state.authorOption}
                    showAdd={this.state.showAdd}
                    closeAdd={this.closeAdd} />
            </div >
        );
    }
});

export default Technology;